Class: Decidim::System::BaseOrganizationForm

Inherits:
Form
  • Object
show all
Includes:
JsonbAttributes, TranslatableAttributes
Defined in:
app/forms/decidim/system/base_organization_form.rb

Overview

A form object to be inherited to create and update organizations from the system dashboard.

Constant Summary collapse

OMNIATH_PROVIDERS_ATTRIBUTES =
Decidim::OmniauthProvider.available.keys.map do |provider|
  Decidim.omniauth_providers[provider].keys.map do |setting|
    if setting == :enabled
      [:"omniauth_settings_#{provider}_enabled", Boolean]
    else
      [:"omniauth_settings_#{provider}_#{setting}", String]
    end
  end
end.flatten(1)

Instance Method Summary collapse

Instance Method Details

#clean_available_authorizationsObject



84
85
86
87
88
# File 'app/forms/decidim/system/base_organization_form.rb', line 84

def clean_available_authorizations
  return unless available_authorizations

  available_authorizations.compact_blank
end

#clean_secondary_hostsObject



78
79
80
81
82
# File 'app/forms/decidim/system/base_organization_form.rb', line 78

def clean_secondary_hosts
  return unless secondary_hosts

  secondary_hosts.split("\n").map(&:chomp).compact_blank
end

#encrypted_omniauth_settingsObject



108
109
110
111
112
113
114
# File 'app/forms/decidim/system/base_organization_form.rb', line 108

def encrypted_omniauth_settings
  encrypted = omniauth_settings.transform_values do |v|
    Decidim::OmniauthProvider.value_defined?(v) ? Decidim::AttributeEncryptor.encrypt(v) : v
  end
  # if all are empty, nil is returned so it does not break ENV vars configuration
  encrypted.values.all?(&:blank?) ? nil : encrypted
end

#encrypted_smtp_settingsObject



94
95
96
97
98
99
100
# File 'app/forms/decidim/system/base_organization_form.rb', line 94

def encrypted_smtp_settings
  smtp_settings["from"] = set_from

  encrypted = smtp_settings.merge(encrypted_password: Decidim::AttributeEncryptor.encrypt(password))
  # if all are empty, nil is returned so it does not break ENV vars configuration
  encrypted.values.all?(&:blank?) ? nil : encrypted
end

#map_model(model) ⇒ Object



69
70
71
72
73
74
75
76
# File 'app/forms/decidim/system/base_organization_form.rb', line 69

def map_model(model)
  self.default_locale = model.default_locale
  self.secondary_hosts = model.secondary_hosts.join("\n")
  self.omniauth_settings = (model.omniauth_settings || {}).transform_values do |v|
    Decidim::OmniauthProvider.value_defined?(v) ? Decidim::AttributeEncryptor.decrypt(v) : v
  end
  self.file_upload_settings = FileUploadSettingsForm.from_model(model.file_upload_settings)
end

#passwordObject



90
91
92
# File 'app/forms/decidim/system/base_organization_form.rb', line 90

def password
  encrypted_password.nil? ? super : Decidim::AttributeEncryptor.decrypt(encrypted_password)
end

#set_fromObject



102
103
104
105
106
# File 'app/forms/decidim/system/base_organization_form.rb', line 102

def set_from
  return from_email if from_label.blank?

  "#{from_label} <#{from_email}>"
end